==> batik_1.5.1.orig.tar.gz: batik-1.5.1.orig/sources/org/apache/batik/svggen/SVGStylingAttributes.java <==
/*

 ============================================================================
                   The Apache Software License, Version 1.1
 ============================================================================

 Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.

 Redistribution and use in source and binary forms, with or without modifica-
 tion, are permitted provided that the following conditions are met:

 1. Redistributions of  source code must  retain the above copyright  notice,
    this list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.

 3. The end-user documentation included with the redistribution, if any, must
    include  the following  acknowledgment:  "This product includes  software
    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
    Alternately, this  acknowledgment may  appear in the software itself,  if
    and wherever such third-party acknowledgments normally appear.

 4. The names "Batik" and  "Apache Software Foundation" must  not  be
    used to  endorse or promote  products derived from  this software without
    prior written permission. For written permission, please contact
    apache@apache.org.

 5. Products  derived from this software may not  be called "Apache", nor may
    "Apache" appear  in their name,  without prior written permission  of the
    Apache Software Foundation.

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
 APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
 DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
 OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
 ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
 (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 This software  consists of voluntary contributions made  by many individuals
 on  behalf of the Apache Software  Foundation. For more  information on the
 Apache Software Foundation, please see <http://www.apache.org/>.

*/

package org.apache.batik.svggen;

import java.util.HashSet;
import java.util.Set;

/**
 * Defines the set of attributes from Exchange SVG that
 * are defined as styling properties in Stylable SVG.
 *
 * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: SVGStylingAttributes.java,v 1.4 2003/08/08 11:39:20 vhardy Exp $
 */
public class SVGStylingAttributes implements SVGSyntax{
    static Set attrSet = new HashSet();

    static {
        attrSet.add(SVG_CLIP_PATH_ATTRIBUTE);
        attrSet.add(SVG_COLOR_INTERPOLATION_ATTRIBUTE);
        attrSet.add(SVG_COLOR_RENDERING_ATTRIBUTE);
        attrSet.add(SVG_ENABLE_BACKGROUND_ATTRIBUTE);
        attrSet.add(SVG_FILL_ATTRIBUTE);
        attrSet.add(SVG_FILL_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_FILL_RULE_ATTRIBUTE);
        attrSet.add(SVG_FILTER_ATTRIBUTE);
        attrSet.add(SVG_FLOOD_COLOR_ATTRIBUTE);
        attrSet.add(SVG_FLOOD_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_FONT_FAMILY_ATTRIBUTE);
        attrSet.add(SVG_FONT_SIZE_ATTRIBUTE);
        attrSet.add(SVG_FONT_WEIGHT_ATTRIBUTE);
        attrSet.add(SVG_FONT_STYLE_ATTRIBUTE);
        attrSet.add(SVG_IMAGE_RENDERING_ATTRIBUTE);
        attrSet.add(SVG_MASK_ATTRIBUTE);
        attrSet.add(SVG_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_SHAPE_RENDERING_ATTRIBUTE);
        attrSet.add(SVG_STOP_COLOR_ATTRIBUTE);
        attrSet.add(SVG_STOP_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_STROKE_ATTRIBUTE);
        attrSet.add(SVG_STROKE_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_STROKE_DASHARRAY_ATTRIBUTE);
        attrSet.add(SVG_STROKE_DASHOFFSET_ATTRIBUTE);
        attrSet.add(SVG_STROKE_LINECAP_ATTRIBUTE);
        attrSet.add(SVG_STROKE_LINEJOIN_ATTRIBUTE);
        attrSet.add(SVG_STROKE_MITERLIMIT_ATTRIBUTE);
        attrSet.add(SVG_STROKE_WIDTH_ATTRIBUTE);
        attrSet.add(SVG_TEXT_RENDERING_ATTRIBUTE);
    }

    /**
     * Attributes that represent styling properties
     */
    public static final Set set = attrSet;
}

==> batik_1.8.orig.tar.gz: batik-1.8/sources/org/apache/batik/svggen/SVGStylingAttributes.java <==
/*

   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
package org.apache.batik.svggen;

import java.util.HashSet;
import java.util.Set;

/**
 * Defines the set of attributes from Exchange SVG that
 * are defined as styling properties in Stylable SVG.
 *
 * @author <a href="mailto:vincent.hardy@eng.sun.com">Vincent Hardy</a>
 * @version $Id: SVGStylingAttributes.java 475477 2006-11-15 22:44:28Z cam $
 */
public class SVGStylingAttributes implements SVGSyntax{
    static Set attrSet = new HashSet();

    static {
        attrSet.add(SVG_CLIP_PATH_ATTRIBUTE);
        attrSet.add(SVG_COLOR_INTERPOLATION_ATTRIBUTE);
        attrSet.add(SVG_COLOR_RENDERING_ATTRIBUTE);
        attrSet.add(SVG_ENABLE_BACKGROUND_ATTRIBUTE);
        attrSet.add(SVG_FILL_ATTRIBUTE);
        attrSet.add(SVG_FILL_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_FILL_RULE_ATTRIBUTE);
        attrSet.add(SVG_FILTER_ATTRIBUTE);
        attrSet.add(SVG_FLOOD_COLOR_ATTRIBUTE);
        attrSet.add(SVG_FLOOD_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_FONT_FAMILY_ATTRIBUTE);
        attrSet.add(SVG_FONT_SIZE_ATTRIBUTE);
        attrSet.add(SVG_FONT_WEIGHT_ATTRIBUTE);
        attrSet.add(SVG_FONT_STYLE_ATTRIBUTE);
        attrSet.add(SVG_IMAGE_RENDERING_ATTRIBUTE);
        attrSet.add(SVG_MASK_ATTRIBUTE);
        attrSet.add(SVG_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_SHAPE_RENDERING_ATTRIBUTE);
        attrSet.add(SVG_STOP_COLOR_ATTRIBUTE);
        attrSet.add(SVG_STOP_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_STROKE_ATTRIBUTE);
        attrSet.add(SVG_STROKE_OPACITY_ATTRIBUTE);
        attrSet.add(SVG_STROKE_DASHARRAY_ATTRIBUTE);
        attrSet.add(SVG_STROKE_DASHOFFSET_ATTRIBUTE);
        attrSet.add(SVG_STROKE_LINECAP_ATTRIBUTE);
        attrSet.add(SVG_STROKE_LINEJOIN_ATTRIBUTE);
        attrSet.add(SVG_STROKE_MITERLIMIT_ATTRIBUTE);
        attrSet.add(SVG_STROKE_WIDTH_ATTRIBUTE);
        attrSet.add(SVG_TEXT_RENDERING_ATTRIBUTE);
    }

    /**
     * Attributes that represent styling properties
     */
    public static final Set set = attrSet;
}
